@@ -24,6 +24,7 @@ from imagen_pytorch.imagen_pytorch import (
     maybe,
     default,
     cast_tuple,
+    cast_uint8_images_to_float,
     eval_decorator,
     check_shape,
     pad_tuple_to_length,
@@ -445,6 +446,8 @@ class ElucidatedImagen(nn.Module):
         device = default(device, self.device)
         self.reset_unets_all_one_device(device = device)
 
+        cond_images = maybe(cast_uint8_images_to_float)(cond_images)
+
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
             text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
             text_embeds, text_masks = map(lambda t: t.to(device), (text_embeds, text_masks))
@@ -469,7 +472,7 @@ class ElucidatedImagen(nn.Module):
         num_unets = len(self.unets)
         cond_scale = cast_tuple(cond_scale, num_unets)
 
-        for unet_number, unet, channel, image_size, unet_hparam, dynamic_threshold, unet_cond_scale in tqdm(zip(range(1, len(self.unets) + 1), self.unets, self.sample_channels, self.image_sizes, self.hparams, self.dynamic_thresholding, cond_scale), disable = not use_tqdm):
+        for unet_number, unet, channel, image_size, unet_hparam, dynamic_threshold, unet_cond_scale in tqdm(zip(range(1, num_unets + 1), self.unets, self.sample_channels, self.image_sizes, self.hparams, self.dynamic_thresholding, cond_scale), disable = not use_tqdm):
 
             context = self.one_unet_in_gpu(unet = unet) if is_cuda else nullcontext()
 
@@ -539,6 +542,9 @@ class ElucidatedImagen(nn.Module):
         unet_number = default(unet_number, 1)
         assert not exists(self.only_train_unet_number) or self.only_train_unet_number == unet_number, 'you can only train on unet #{self.only_train_unet_number}'
 
+        images = cast_uint8_images_to_float(images)
+        cond_images = maybe(cast_uint8_images_to_float)(cond_images)
+
         unet_index = unet_number - 1
         
         unet = default(unet, lambda: self.get_unet(unet_number))
