@@ -59,6 +59,11 @@ def cast_tuple(val, length = None):
 
     return output
 
+def cast_uint8_images_to_float(images):
+    if not images.dtype == torch.uint8:
+        return images
+    return images / 127.5
+
 def module_device(module):
     return next(module.parameters()).device
 
@@ -1976,6 +1981,8 @@ class Imagen(nn.Module):
         device = default(device, self.device)
         self.reset_unets_all_one_device(device = device)
 
+        cond_images = maybe(cast_uint8_images_to_float)(cond_images)
+
         if exists(texts) and not exists(text_embeds) and not self.unconditional:
             text_embeds, text_masks = self.encode_text(texts, return_attn_mask = True)
             text_embeds, text_masks = map(lambda t: t.to(device), (text_embeds, text_masks))
@@ -2130,6 +2137,9 @@ class Imagen(nn.Module):
         unet_number = default(unet_number, 1)
         assert not exists(self.only_train_unet_number) or self.only_train_unet_number == unet_number, 'you can only train on unet #{self.only_train_unet_number}'
 
+        images = cast_uint8_images_to_float(images)
+        cond_images = maybe(cast_uint8_images_to_float)(cond_images)
+
         unet_index = unet_number - 1
         
         unet = default(unet, lambda: self.get_unet(unet_number))
